
-- Addon options, not to be confused with dialog options.

local THIS_VERSION = GetAddOnMetadata("Gossipmonger", "Version");

local L = GOSSIPMONGER_STRINGS
local KeySelectDropDown

Gossipmonger.DefaultSettings = {
  Version = THIS_VERSION,
  skipIsDefault = true,
  --informOnSkip_SCT = false,
  informOnSkip_log = false,
  alwaysInformWithName = false,
  informOnSkip_nobubble = true,
  showGossipMirrorOnSkip = true,
  delayShowingMirror = true,
  showGossipMirrorOnQuestSelect = false,
  showGossipMirrorOnQuestJump = true,
  greetingModifierKey = 2,
  Filter_WoWDefault = true,
  Filter_Accuracy = true,
  Filter_Mundane = false,
};





local function UpdateLabel()
  local KEYTIP
  if (Gossipmonger_Settings.skipIsDefault) then
    Gossipmonger_GreetingModDropdown:SetLabel(L.MODIFIERKEY_LABEL_DONOT)
	KEYTIP = L.MODIFIERKEY_TOOLTIP_KEY_DONOT
  else
    Gossipmonger_GreetingModDropdown:SetLabel(L.MODIFIERKEY_LABEL_DO)
    KEYTIP = L.MODIFIERKEY_TOOLTIP_KEY_DO
  end
  for k,v in ipairs(KeySelectDropDown) do
    if (v.key) then
      v.tooltipText = KEYTIP:format(v.key)
	end
  end
end

local function tooltip_WDFilter(self, tooltip)
  tooltip:AddLine(L.FILTEROPT_WOWDEFAULT_TIP, nil, nil, nil, 1);
  tooltip:AddLine(L.FILTEROPT_WOWDEFAULT_TIP2, nil, nil, nil, 1);
  tooltip:AddLine(L.FILTEROPT_WOWDEFAULT_TIP3, nil, nil, nil, 1);
  tooltip:AddTexture("Interface\\GossipFrame\\GossipGossipIcon");
  tooltip:AddLine(L.FILTEROPT_WOWDEFAULT_TIP4, nil, nil, nil, 1);
end


function Gossipmonger.CreateOptions(THIS_TITLE, BreakMirror, UpdateStandardFilters)
  --local KEY, KEYTIP = L.KEY, L.MODIFIERKEY_TOOLTIP_KEY
  local KEY = L.KEY
  KeySelectDropDown = {
    {
      text = KEY:format(L.ALT),
      tooltipTitle = KEY:format(L.ALT),
      --tooltipText = KEYTIP:format(L.ALT),
	  key = L.ALT,
      value = 0
    },
    {
      text = KEY:format(L.CTRL),
      tooltipTitle = KEY:format(L.CTRL),
      --tooltipText = KEYTIP:format(L.CTRL),
	  key = L.CTRL,
      value = 1
    },
    {
      text = KEY:format(L.SHIFT),
      tooltipTitle = KEY:format(L.SHIFT),
      --tooltipText = KEYTIP:format(L.SHIFT),
	  key = L.SHIFT,
      value = 2
    },
    {
      text = L.MODIFIERKEY_NONE,
      tooltipTitle = L.MODIFIERKEY_NONE,
      tooltipText = L.MODIFIERKEY_NONE_TOOLTIP,
      value = 3
    };
  };

  --local scttext = L.INFORMONSKIP_SCT
  --if (not SCT) then  scttext = L.INFORMONSKIP_SCT_DISABLED:format(scttext);  end

  local panel, oldver = TjOptions.CreatePanel(THIS_TITLE, nil, {
  	title = THIS_TITLE.." v"..THIS_VERSION,
  	items = {
  		 { variable = "skipIsDefault", text = L.SKIPISDEFAULT, tooltip = L.SKIPISDEFAULT_TIP, tooltip2 = L.SKIPISDEFAULT_TIP2, OnChange = UpdateLabel },
  		 { variable = "greetingModifierKey", type = "dropdown", name = "Gossipmonger_GreetingModDropdown",
  		   text = L.MODIFIERKEY_LABEL_DONOT, menu = KeySelectDropDown, width = 85 },
  		 { variable = "showGossipMirrorOnSkip", text = L.SHOWBUBBLE, tooltip = L.SHOWBUBBLE_TIP },
  		 { variable = "delayShowingMirror", text = L.SHOWBUBBLE_DELAY,
  		   tooltip = L.SHOWBUBBLE_DELAY_TOOLTIP, xOffset = 14 },
  		 { variable = "showGossipMirrorOnQuestSelect", text = L.SHOWBUBBLE_QUESTSELECT,
  		   tooltip = L.SHOWBUBBLE_QUESTSELECT_TOOLTIP, tooltip2 = L.SHOWBUBBLE_QUESTSELECT_TOOLTIP2, xOffset = 0, OnChange = BreakMirror },
  		 { variable = "showGossipMirrorOnQuestJump", text = L.SHOWBUBBLE_QUESTJUMP,
  		   tooltip = L.SHOWBUBBLE_QUESTJUMP_TOOLTIP },

  		 { type = "label", text = L.FILTEROPT_STANDARD_LABEL, topBuffer = 10 },
  		 { variable = "Filter_WoWDefault", text = L.FILTEROPT_WOWDEFAULT, tooltip = tooltip_WDFilter,
  		   OnChange = UpdateStandardFilters },
  		 { variable = "Filter_Accuracy", text = L.FILTEROPT_ACCURACY,
  		   tooltip = { L.FILTEROPT_ACCURACY_TIP, L.FILTEROPT_ACCURACY_TIP2, L.FILTEROPT_ACCURACY_TIP3 }, OnChange = UpdateStandardFilters },
  		 { variable = "Filter_Mundane", text = L.FILTEROPT_MUNDANE,
  		   tooltip = L.FILTEROPT_MUNDANE_TIP, tooltip2 = L.FILTEROPT_MUNDANE_TIP2, OnChange = UpdateStandardFilters },

  		 { type = "label", text = L.MISC_LABEL, topBuffer = 10 },
  		 { variable = "informOnSkip_log", type = "checkbox", text = L.INFORMONSKIP_CHAT },
  		 { variable = "informOnSkip_nobubble", type = "checkbox", text = L.INFORMONSKIP_NOBUBBLE, xOffset = 14 },
  		 { variable = "alwaysInformWithName", type = "checkbox", text = L.INFORMONSKIP_NAMEONLY,
  		   tooltip = L.INFORMONSKIP_NAMEONLY_TOOLTIP, xOffset = 14 },

		   --[[
  		 { type = "label", text = L.INFORMONSKIP, xOffset = 0 },
  		 --{ variable = "informOnSkip_SCT", type = "checkboxsmall", text = scttext, xOffset = 14 },
  		 { variable = "informOnSkip_log", type = "checkboxsmall", text = L.INFORMONSKIP_CHAT, xOffset = 14 },
  		 { variable = "alwaysInformWithName", type = "checkboxsmall", text = L.INFORMONSKIP_NAMEONLY,
  		   tooltip = L.INFORMONSKIP_NAMEONLY_TOOLTIP },
		   --]]
  	},
  	variables = "Gossipmonger_Settings",
  	defaults = Gossipmonger.DefaultSettings,
  	OnShow = UpdateLabel
  });

  return panel, oldver
end
